Contributing, Citing and Contact
================================

For now, please refer to this repository. A paper, to which you can then
refer, will be published in the nearby future. If you have any
questions, are experiencing bugs in the GENDIS implementation, or would
like to contribute, please feel free to create an issue/pull request in
this repository or take contact with me at
gilles(dot)vandewiele(at)ugent(dot)be